## -*- coding: utf-8; mode: python; -*-
# -*- coding: utf-8; -*-
"""
${name} setup script
"""

import os
from setuptools import setup, find_packages


here = os.path.abspath(os.path.dirname(__file__))
exec(open(os.path.join(here, '${python_name}', '_version.py')).read())
README = open(os.path.join(here, 'README.md')).read()


requires = [
    #
    # Version numbers within comments below have specific meanings.
    # Basically the 'low' value is a "soft low," and 'high' a "soft high."
    # In other words:
    #
    # If either a 'low' or 'high' value exists, the primary point to be
    # made about the value is that it represents the most current (stable)
    # version available for the package (assuming typical public access
    # methods) whenever this project was started and/or documented.
    # Therefore:
    #
    # If a 'low' version is present, you should know that attempts to use
    # versions of the package significantly older than the 'low' version
    # may not yield happy results.  (A "hard" high limit may or may not be
    # indicated by a true version requirement.)
    #
    # Similarly, if a 'high' version is present, and especially if this
    # project has laid dormant for a while, you may need to refactor a bit
    # when attempting to support a more recent version of the package.  (A
    # "hard" low limit should be indicated by a true version requirement
    # when a 'high' version is present.)
    #
    # In any case, developers and other users are encouraged to play
    # outside the lines with regard to these soft limits.  If bugs are
    # encountered then they should be filed as such.
    #
    # package                           # low                   high

    'invoke',                           # 1.4.1
    'rattail[auth,db,bouncer]',         # 0.9.141
    'rattail-fabric2',                  # 0.2.1

    % if has_db:
    'psycopg2',                         # 2.8.4
    % endif

    % if has_web:
    'Tailbone',                         # 0.8.72
    % endif

    % if integrates_with == 'catapult':
    # TODO: must cap this for now, b/c it breaks Catapult integration?!
    # (something about "Syntax error near 'ROWS'" with grid queries)
    'SQLAlchemy<1.3',                   #                       1.2.19
    'onager',                           # 0.2.8
    'rattail-onager',                   # 0.2.1
    % if has_web:
    'tailbone-onager',                  # 0.2.3
    % endif
    % endif
]


setup(
    name = "${python_project_name}",
    version = __version__,
    author = "Your Name",
    author_email = "you@example.com",
    # url = "",
    description = "Custom Rattail project for ${organization}",
    long_description = README,

    classifiers = [
        # TODO: remove this if you intend to publish your project!
        # (it's here by default, to prevent accidental publishing)
        'Private :: Do Not Upload',
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        % if has_web or has_web_api:
        'Environment :: Web Environment',
        'Framework :: Pyramid',
        % endif
        'Intended Audience :: Developers',
        'Natural Language :: English',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Topic :: Office/Business',
    ],

    install_requires = requires,
    packages = find_packages(),
    include_package_data = True,
    # zip_safe = False,

    entry_points = {

        'rattail.config.extensions': [
            '${python_name} = ${python_name}.config:${studly_name}Config',
        ],

        'console_scripts': [
            '${python_name} = ${python_name}.commands:main',
        ],

        '${python_name}.commands': [
            'hello = ${python_name}.commands:HelloWorld',
        ],
        % if has_web:

        'paste.app_factory': [
            'main = ${python_name}.web.app:main',
        ],
        % endif
    },
)
